OptionsDiff class

Difference between the current MathOptions and the desired MathOptions.

This is used to declaratively describe the modifications to MathOptions.

Constructors

OptionsDiff({MathStyle? style, Color? color, MathSize? size, PartialFontOptions? textFontOptions, FontOptions? mathFontOptions})
const

Properties

color → Color?
Override text color.
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this diff has no effect.
no setter
mathFontOptions → FontOptions?
Override math-mode font.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → MathSize?
Override declared size.
final
style → MathStyle?
Override MathOptions.style
final
textFontOptions → PartialFontOptions?
Merge font differences into text-mode font options.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMathFont() → OptionsDiff
Strip math font changes.
removeStyle() → OptionsDiff
Strip the style change.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited