SyntaxTree class

Roslyn's Red-Green Tree

Description of Roslyn's Red-Green Tree

Available extensions

Constructors

SyntaxTree({required EquationRowNode greenRoot})

Properties

greenRoot → EquationRowNode
Root of the green tree
final
hashCode → int
The hash code for this object.
no setterinherited
root → SyntaxNode
Root of the red tree
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildWidget(MathOptions options) → Widget
findLowestCommonRowNode(int position1, int position2) → EquationRowNode
findNodeManagesPosition(int position) → EquationRowNode
findNodesAtPosition(int position) → List<SyntaxNode>
findSelectedNodes(int position1, int position2) → List<GreenNode>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceNode(SyntaxNode pos, GreenNode newNode) → SyntaxTree
Replace node at pos with newNode
texBreak({int relPenalty = 500, int binOpPenalty = 700, bool enforceNoBreak = true}) → BreakResult<SyntaxTree>

Available on SyntaxTree, provided by the SyntaxTreeTexStyleBreakExt extension

Line breaking results using standard TeX-style line breaking.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited