Unit enum

Inheritance
Available extensions

Values

pt → const Unit
mm → const Unit
cm → const Unit
inches → const Unit
bp → const Unit
pc → const Unit
dd → const Unit
cc → const Unit
nd → const Unit
nc → const Unit
sp → const Unit
px → const Unit
ex → const Unit
em → const Unit
mu → const Unit
lp → const Unit
cssEm → const Unit

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on Unit, provided by the UnitExt extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toPt → double?

Available on Unit, provided by the UnitExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Unit>
A constant List of the values in this enum, in order of their declaration.