MacroDefinition class

Constructors

MacroDefinition(MacroExpansion expand(MacroContext context), {bool unexpandable = false})
const
MacroDefinition.fromCtxString(String expand(MacroContext))
MacroDefinition.fromMacroExpansion(MacroExpansion output)
MacroDefinition.fromString(String output)

Properties

expand → MacroExpansion Function(MacroContext context)
final
expandable → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unexpandable → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited